@@ -49,7 +49,6 @@ class Alarms:
         :param lower_alarm_interval_index: 
         :param upper_alarm_interval_index: 
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {}
@@ -61,7 +60,6 @@ class Alarms:
     @builtins.property
     def lower_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("lower_alarm_interval_index")
@@ -70,7 +68,6 @@ class Alarms:
     @builtins.property
     def upper_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("upper_alarm_interval_index")
@@ -104,7 +101,6 @@ class ArbitraryIntervals:
         :param absolute: 
         :param intervals: 
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -115,7 +111,6 @@ class ArbitraryIntervals:
     @builtins.property
     def absolute(self) -> builtins.bool:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("absolute")
@@ -125,7 +120,6 @@ class ArbitraryIntervals:
     @builtins.property
     def intervals(self) -> typing.List["ScalingInterval"]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("intervals")
@@ -162,7 +156,6 @@ class CompleteScalingInterval:
         :param upper: 
         :param change: 
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -175,7 +168,6 @@ class CompleteScalingInterval:
     @builtins.property
     def lower(self) -> jsii.Number:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("lower")
@@ -185,7 +177,6 @@ class CompleteScalingInterval:
     @builtins.property
     def upper(self) -> jsii.Number:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("upper")
@@ -195,7 +186,6 @@ class CompleteScalingInterval:
     @builtins.property
     def change(self) -> typing.Optional[jsii.Number]:
         """
-        stability
         :stability: experimental
         """
         result = self._values.get("change")
@@ -216,7 +206,6 @@ class CompleteScalingInterval:
 @jsii.interface(jsii_type="@aws-cdk/aws-autoscaling-common.IRandomGenerator")
 class IRandomGenerator(typing_extensions.Protocol):
     """
-    stability
     :stability: experimental
     """
 
@@ -227,7 +216,6 @@ class IRandomGenerator(typing_extensions.Protocol):
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> builtins.bool:
         """
-        stability
         :stability: experimental
         """
         ...
@@ -238,7 +226,6 @@ class IRandomGenerator(typing_extensions.Protocol):
         :param min: -
         :param max: -
 
-        stability
         :stability: experimental
         """
         ...
@@ -246,7 +233,6 @@ class IRandomGenerator(typing_extensions.Protocol):
 
 class _IRandomGeneratorProxy:
     """
-    stability
     :stability: experimental
     """
 
@@ -255,7 +241,6 @@ class _IRandomGeneratorProxy:
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> builtins.bool:
         """
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "nextBoolean", [])
@@ -266,7 +251,6 @@ class _IRandomGeneratorProxy:
         :param min: -
         :param max: -
 
-        stability
         :stability: experimental
         """
         return jsii.invoke(self, "nextInt", [min, max])
@@ -285,13 +269,12 @@ class ScalingInterval:
         lower: typing.Optional[jsii.Number] = None,
         upper: typing.Optional[jsii.Number] = None,
     ) -> None:
-        """A range of metric values in which to apply a certain scaling operation.
+        """(experimental) A range of metric values in which to apply a certain scaling operation.
 
-        :param change: The capacity adjustment to apply in this interval. The number is interpreted differently based on AdjustmentType: - ChangeInCapacity: add the adjustment to the current capacity. The number can be positive or negative. - PercentChangeInCapacity: add or remove the given percentage of the current capacity to itself. The number can be in the range [-100..100]. - ExactCapacity: set the capacity to this number. The number must be positive.
-        :param lower: The lower bound of the interval. The scaling adjustment will be applied if the metric is higher than this value. Default: Threshold automatically derived from neighbouring intervals
-        :param upper: The upper bound of the interval. The scaling adjustment will be applied if the metric is lower than this value. Default: Threshold automatically derived from neighbouring intervals
+        :param change: (experimental) The capacity adjustment to apply in this interval. The number is interpreted differently based on AdjustmentType: - ChangeInCapacity: add the adjustment to the current capacity. The number can be positive or negative. - PercentChangeInCapacity: add or remove the given percentage of the current capacity to itself. The number can be in the range [-100..100]. - ExactCapacity: set the capacity to this number. The number must be positive.
+        :param lower: (experimental) The lower bound of the interval. The scaling adjustment will be applied if the metric is higher than this value. Default: Threshold automatically derived from neighbouring intervals
+        :param upper: (experimental) The upper bound of the interval. The scaling adjustment will be applied if the metric is lower than this value. Default: Threshold automatically derived from neighbouring intervals
 
-        stability
         :stability: experimental
         """
         self._values: typing.Dict[str, typing.Any] = {
@@ -304,7 +287,7 @@ class ScalingInterval:
 
     @builtins.property
     def change(self) -> jsii.Number:
-        """The capacity adjustment to apply in this interval.
+        """(experimental) The capacity adjustment to apply in this interval.
 
         The number is interpreted differently based on AdjustmentType:
 
@@ -315,7 +298,6 @@ class ScalingInterval:
         - ExactCapacity: set the capacity to this number. The number must
           be positive.
 
-        stability
         :stability: experimental
         """
         result = self._values.get("change")
@@ -324,14 +306,12 @@ class ScalingInterval:
 
     @builtins.property
     def lower(self) -> typing.Optional[jsii.Number]:
-        """The lower bound of the interval.
+        """(experimental) The lower bound of the interval.
 
         The scaling adjustment will be applied if the metric is higher than this value.
 
-        default
         :default: Threshold automatically derived from neighbouring intervals
 
-        stability
         :stability: experimental
         """
         result = self._values.get("lower")
@@ -339,14 +319,12 @@ class ScalingInterval:
 
     @builtins.property
     def upper(self) -> typing.Optional[jsii.Number]:
-        """The upper bound of the interval.
+        """(experimental) The upper bound of the interval.
 
         The scaling adjustment will be applied if the metric is lower than this value.
 
-        default
         :default: Threshold automatically derived from neighbouring intervals
 
-        stability
         :stability: experimental
         """
         result = self._values.get("upper")
